@@ -1,25 +1,25 @@
 // SPDX-FileCopyrightText: 2025 Manuel Schneider
+// SPDX-License-Identifier: MIT
 
 #pragma once
 #include <albert/export.h>
-#include <memory>
-class QByteArray;
 class QNetworkAccessManager;
 class QNetworkReply;
-class QNetworkRequest;
 class QString;
-class QUrlQuery;
 
-namespace albert::util
+namespace albert
 {
 
+/// \addtogroup util_net
+/// @{
+
 ///
 /// Returns a global, threadlocal QNetworkAccessManager.
 ///
 ALBERT_EXPORT QNetworkAccessManager &network();
 
 ///
-/// Blocks until `reply` is finished.
+/// Blocks until _reply_ is finished.
 ///
 ALBERT_EXPORT QNetworkReply *await(QNetworkReply *reply);
 
@@ -33,26 +33,6 @@ ALBERT_EXPORT QString percentEncoded(const QString &string);
 ///
 ALBERT_EXPORT QString percentDecoded(const QString &string);
 
-}
-
-namespace albert::detail {
-
-/// Blocks execution
-class ALBERT_EXPORT RateLimiter
-{
-public:
-    RateLimiter(unsigned int ms);
-    ~RateLimiter();
-
-    /// Blocks until the next request is allowed.
-    /// If `valid` is false, it returns immediately.
-    const bool &debounce(const bool &valid);
-
-private:
-
-    class Private;
-    std::unique_ptr<Private> d;
-
-};
+/// @}
 
 }
